==> qtjambi-remoteobjects-6.2.12-sources.jar: io/qt/remoteobjects/QRemoteObjectRegistryHost.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>A (Host/Registry) node on a Qt Remote Objects network</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qremoteobjectregistryhost.html">QRemoteObjectRegistryHost</a></p>
 */
public class QRemoteObjectRegistryHost extends io.qt.remoteobjects.QRemoteObjectHostBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectRegistryHost.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QUrl, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectRegistryHost(io.qt.core.@NonNull QUrl registryAddress) {
        this(registryAddress, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QUrl, io.qt.core.QObject)}</p>
     * <p>with: </p><ul>
     * <li><code>registryAddress = new io.qt.core.QUrl()</code></li>
     * <li><code>parent = null</code></li>
     * </ul>
     */
    public QRemoteObjectRegistryHost() {
        this(new io.qt.core.QUrl(), (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qremoteobjectregistryhost.html#QRemoteObjectRegistryHost">QRemoteObjectRegistryHost::QRemoteObjectRegistryHost(QUrl,QObject*)</a></p>
     */
    public QRemoteObjectRegistryHost(io.qt.core.@NonNull QUrl registryAddress, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, registryAddress, parent);
    }
    
    private native static void initialize_native(QRemoteObjectRegistryHost instance, io.qt.core.QUrl registryAddress, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qremoteobjectnode.html#registryUrl-prop">QRemoteObjectNode::setRegistryUrl(QUrl)</a></p>
     */
    @QtUninvokable
    public boolean setRegistryUrl(io.qt.core.@NonNull QUrl registryUrl){
        return setRegistryUrl_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(registryUrl));
    }
    
    @QtUninvokable
    private native boolean setRegistryUrl_native_cref_QUrl(long __this__nativeId, long registryUrl);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QRemoteObjectRegistryHost(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QRemoteObjectRegistryHost(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRemoteObjectRegistryHost instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-remoteobjects-6.5.0-sources.jar: io/qt/remoteobjects/QRemoteObjectRegistryHost.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>A (Host/Registry) node on a Qt Remote Objects network</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qremoteobjectregistryhost.html">QRemoteObjectRegistryHost</a></p>
 */
public class QRemoteObjectRegistryHost extends io.qt.remoteobjects.QRemoteObjectHostBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectRegistryHost.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectRegistryHost(io.qt.core.QUrl, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectRegistryHost(io.qt.core.@NonNull QUrl registryAddress) {
        this(registryAddress, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectRegistryHost(io.qt.core.QUrl, io.qt.core.QObject)}</p>
     * <p>with: </p><ul>
     * <li><code>registryAddress = new io.qt.core.QUrl()</code></li>
     * <li><code>parent = null</code></li>
     * </ul>
     */
    public QRemoteObjectRegistryHost() {
        this(new io.qt.core.QUrl(), (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qremoteobjectregistryhost.html#QRemoteObjectRegistryHost">QRemoteObjectRegistryHost::QRemoteObjectRegistryHost(QUrl,QObject*)</a></p>
     */
    public QRemoteObjectRegistryHost(io.qt.core.@NonNull QUrl registryAddress, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, registryAddress, parent);
    }
    
    private native static void initialize_native(QRemoteObjectRegistryHost instance, io.qt.core.QUrl registryAddress, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qremoteobjectnode.html#registryUrl-prop">QRemoteObjectNode::setRegistryUrl(QUrl)</a></p>
     */
    @QtUninvokable
    public boolean setRegistryUrl(io.qt.core.@NonNull QUrl registryUrl){
        return setRegistryUrl_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(registryUrl));
    }
    
    @QtUninvokable
    private native boolean setRegistryUrl_native_cref_QUrl(long __this__nativeId, long registryUrl);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QRemoteObjectRegistryHost(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QRemoteObjectRegistryHost(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRemoteObjectRegistryHost instance, QDeclarativeConstructor constructor);
    
}
